@@ -5,7 +5,6 @@ import json
 import requests
 from requests.adapters import HTTPAdapter
 from requests.auth import HTTPBasicAuth
-from laipvt.helper.errors import Helper
 from laipvt.interface.middlewareinterface import MiddlewareInterface
 from laipvt.handler.confighandler import CheckResultHandler
 from laipvt.handler.middlewarehandler import HarborConfigHandler
@@ -42,6 +41,7 @@ class HarborController(MiddlewareInterface):
         如果是多机Harbor 只将data目录拷贝到第一台harbor上，传输第二台的时候将data.tar.gz过滤掉，使用内部同步机制，节约部署时间
         :return:
         """
+        log.info("渲染分发 Harbor 安装包及配置文件")
         for num_id, server in enumerate(self.harbor_server):
             self.harbor_cfg["harbor"]["localhost_ip"] = server.ipaddress
             FileTemplate(self.harbor_cfg, self.harbor_conf_template, self.harbor_conf_tmp).fill()
@@ -61,6 +61,7 @@ class HarborController(MiddlewareInterface):
         return res
 
     def _install_harbor(self):
+        log.info("安装harbor")
         cmd = BASH_RUN.format(path_join(self.base_dir, "install.sh"))
         res = self.ssh_cli(cmd)
         if res["code"] != 0:
@@ -92,23 +93,29 @@ class HarborController(MiddlewareInterface):
         res_list = ssh_cli.run_cmdlist(cmd)
         for res in res_list:
             if res["code"] != 0:
-                log.error(Helper().DECOMPRESS_HARBOR_DATA_ERROR.format(res["stdout"], res["stderr"]))
+                log.error("Harbor Data数据解压或授权失败:{} {}".format(res["stdout"], res["stderr"]))
                 exit(2)
 
     def _start(self):
         compose_cmd = ComposeModel(self.docker_compose_file)
         for server in self.harbor_server:
-            log.info(Helper().START_MIDDLEWARE_SERVICE.format(server.ipaddress, self.middleware_name))
+            log.info("启动 %s %s服务" % (server.ipaddress, self.middleware_name))
             ssh_cli = ssh_obj(ip=server.ipaddress, user=server.username, password=server.password, port=server.port)
             try:
                 res = ssh_cli.run_cmd(compose_cmd.up())
+                # for res in self.ssh_cli(compose_cmd.up()):
                 if res["code"] != 0:
-                    log.error(Helper().START_MIDDLEWARE_SERVICE_ERROR.format(res["stderr"], res["stdout"]))
+                    log.error("启动 %s: %s服务失败: %s %s" % (
+                        server.ipaddress, self.middleware_name,
+                        res["stdout"], res["stderr"]
+                        ))
                     exit(2)
                 res = ssh_cli.run_cmd(ENABLE_HARBOR_SERVICE)
                 if res["code"] != 0:
-                    log.error(Helper().START_MIDDLEWARE_SERVICE_ERROR.format(res["stderr"], res["stdout"]))
-                    exit(2)
+                    log.error("将%s: %s服务开机启动失败: %s %s" % (
+                        server.ipaddress, self.middleware_name,
+                        res["stdout"], res["stderr"]
+                        ))
             except Exception as e:
                 log.error(e)
                 exit(2)
@@ -125,17 +132,13 @@ class HarborController(MiddlewareInterface):
                 url = "http://{IP}:{PORT}/api/v2.0/health".format(
                     IP=server.ipaddress, PORT=self.harbor_cfg["harbor"]["http_port"]
                 )
-                log.info(Helper().CHECK_MIDDLEWARE_SERVICE.format(self.middleware_name,
-                                                                  server.ipaddress,
-                                                                  self.harbor_cfg["harbor"]["http_port"]))
+                log.info("检查 {}:{} 上的 Harbor 健康性".format(server.ipaddress, self.harbor_cfg["harbor"]["http_port"]))
                 result = s.get(url, timeout=5).json()
                 if result["status"] == "healthy":
-                    log.info(Helper().CHECK_MIDDLEWARE_SERVICE_PORT_SUCCEED.format(server.ipaddress,
-                                                                                   self.harbor_cfg["harbor"]["http_port"]))
+                    log.info("{} Harbor 服务运行正常".format(server.ipaddress))
                 else:
-                    log.error(Helper().CHECK_MIDDLEWARE_SERVICE_PORT_FAILED.format(server.ipaddress,
-                                                                                   self.harbor_cfg["harbor"]["http_port"]))
-                    log.error(result)
+                    log.error("{IP} 上的 Harbor 服务异常".format(IP=server.ipaddress))
+                    log.error("错误日志: {}".format(result))
                     exit(2)
         except Exception as e:
             log.error(e)
@@ -146,23 +149,23 @@ class HarborController(MiddlewareInterface):
         只修改第一台Harbor的密码即可，第二台使用Habor配置文件中的密码，所以无需修改
         :return:
         """
-        log.info(Helper().CHANGE_HARBOR_PASSWORD)
+        log.info("修改 Harbor 登陆密码")
         try:
+            # for server in self.harbor_server:
             url = "http://{IP}:{PORT}/api/v2.0/users/1/password".format(
                 IP=self.master_harbor.ipaddress, PORT=self.harbor_cfg["harbor"]["http_port"])
             headers = {"Content-Type": "application/json"}
             data_dit = {"old_password": "Harbor12345", "new_password": "{}".format(self.harbor_cfg["harbor"]["password"])}
             result = requests.put(url=url, json=data_dit, headers=headers, auth=HTTPBasicAuth('admin', 'Harbor12345'))
             if result:
-                log.info(Helper().CHANGE_HARBOR_PASSWORD_SUCCEED)
+                log.info("{} Harbor 密码修改成功".format(self.master_harbor.ipaddress))
             else:
-                log.error(Helper().CHANGE_HARBOR_PASSWORD_FAILED)
+                log.error("{} Harbor 密码修改失败,新密码至少包含1个大写字母、1个小写字母和1个数字".format(self.master_harbor.ipaddress))
                 log.error(result)
                 exit(2)
         except Exception as e:
-            log.error(Helper().CHECK_MIDDLEWARE_SERVICE_PORT_FAILED.format(self.master_harbor.ipaddress,
-                                                                           self.harbor_cfg["harbor"]["http_port"]))
             log.error(e)
+            log.error("{} Harbor 密码修改失败,请检查Harbor服务是否正常启动或端口是否可达".format(self.master_harbor.ipaddress))
             exit(2)
 
     def registries(self):
@@ -194,8 +197,11 @@ class HarborController(MiddlewareInterface):
             }
             res = self.interface_res(url, data)
             if res.status_code != 201:
-                log.error(Helper().HARBOR_REG_CONFIG_FAILED.format(harbor_ipaddress, res.status_code))
+                log.error(
+                    "{} Harbor 仓库管理配置失败, 状态码{} ".format(harbor_ipaddress, res.status_code))
                 exit(2)
+            else:
+                log.info("{} Harbor 仓库管理配置成功 ".format(harbor_ipaddress))
 
     def interface_res(self, url, data):
         try:
@@ -252,9 +258,10 @@ class HarborController(MiddlewareInterface):
                 res = put(url, json.dumps(data), timeout=5,
                           auth=('admin', '{}'.format(self.harbor_cfg["harbor"]["password"])))
             if res.status_code == 200 or res.status_code == 201:
-                log.info(Helper().HARBOR_REPLICATION_SUCCEED.format(res.status_code))
+                log.info("Harbor 复制管理配置成功 ")
             else:
-                log.error(Helper().HARBOR_REPLICATION_FAILED.format(res.status_code))
+                log.error(
+                    "Harbor 复制管理配置失败, 状态码{} ".format(res.status_code))
                 exit(2)
 
     def get_policies_id(self):
@@ -285,12 +292,13 @@ class HarborController(MiddlewareInterface):
                     self.harbor_cfg["harbor"]["harbor_http_port"])
         res = self.interface_res(url, data)
         if res.status_code != 201:
-            log.error(Helper().HARBOR_SYNC_FAILED.format(res.status_code))
+            log.error("Harbor 同步镜像失败, 状态码{} ".format(res.status_code))
             exit(2)
         else:
-            log.info(Helper().HARBOR_SYNC_SUCCEED.format(res.status_code))
+            log.info("Harbor镜像同步成功")
 
     def _proxy_on_nginx(self):
+        log.info("渲染 Nginx 代理配置文件")
         FileTemplate(self.harbor_cfg, self.harbor_nginx_template, self.harbor_nginx_tmp).fill()
         self.update_nginx_config()
         # self.generate_docker_compose_file(self.harbor_cfg)
