@@ -10,7 +10,6 @@ from laipvt.sysutil.template import FileTemplate
 from laipvt.sysutil.util import path_join, ssh_obj, log, status_me
 from laipvt.model.cmd import ComposeModel
 from laipvt.sysutil.siber_main import Mage_test
-from laipvt.helper.errors import Helper
 
 
 class SiberController(MiddlewareInterface):
@@ -31,7 +30,7 @@ class SiberController(MiddlewareInterface):
 		self.casid_basic_list = []
 
 	def _generic_config(self):
-		# log.info("渲染 Siber 配置文件")
+		log.info("渲染 Siber 配置文件")
 		for num_id in range(len(self.list_conf)):
 			dest = path_join(self.conf_template, self.list_conf[num_id])
 			src_tmp = path_join(self.conf_tmp, self.list_conf[num_id])
@@ -43,7 +42,7 @@ class SiberController(MiddlewareInterface):
 		self._send_docker_compose_file(self.master_server[0])
 
 	def _send_docker_compose_file(self, host):
-		log.info(Helper().SEND_FILE.format(self.docker_compose_file_tmp, host.ipaddress, self.docker_compose_file))
+		log.info("分发%s docker-compose配置文件至 %s" % (self.middleware_name, host.ipaddress))
 		ssh_cli = ssh_obj(ip=host.ipaddress, user=host.username, password=host.password, port=host.port)
 		try:
 			ssh_cli.put(self.docker_compose_file_tmp, self.docker_compose_file)
@@ -55,26 +54,31 @@ class SiberController(MiddlewareInterface):
 
 	def _init_siber(self):
 		super().wait_for_service_start()
-		log.info(Helper().INIT_SIBER_MONGO_DATA)
+		log.info("初始化 siber-mongo 数据")
 		try:
 			init_mongo_cmd = "docker exec siber-mongo mongorestore -u admin -p admin -d admin siber_mongo/siber"
 			server = self.master_server[0]
 			ssh_cli = ssh_obj(ip=server.ipaddress, user=server.username, password=server.password, port=server.port)
 			res = ssh_cli.run_cmd(init_mongo_cmd)
 			if res["code"] != 0:
-				log.error(Helper().INIT_SIBER_MONGO_DATA_ERROR.format(res["stderr"]))
+				log.error("初始化 siber-mongo 数据失败:{}".format(res["stderr"]))
+			else:
+				log.info("初始化 siber-mongo 数据成功")
 		except Exception as e:
-			log.error(Helper().INIT_SIBER_MONGO_DATA_ERROR.format(e))
+			log.error(e)
+			log.error("初始化mongo数据失败")
 
 	def _start(self):
 		compose_cmd = ComposeModel(self.docker_compose_file)
 		for server in self.master_server[:1]:
-			log.info(Helper().START_MIDDLEWARE_SERVICE.format(server.ipaddress, self.middleware_name))
+			log.info("启动 %s: %s服务" % (server.ipaddress, self.middleware_name))
 			ssh_cli = ssh_obj(ip=server.ipaddress, user=server.username, password=server.password, port=server.port)
 			try:
 				res = ssh_cli.run_cmd(compose_cmd.up())
-				if res["code"] != 0:
-					log.error(Helper().START_MIDDLEWARE_SERVICE_ERROR.format(res["stderr"], res["stdout"]))
+				if res["code"] == 0:
+					log.info("启动 %s %s 服务成功" % (server.ipaddress, self.middleware_name))
+				else:
+					log.error("启动 %s %s 服务失败: %s " % (server.ipaddress, self.middleware_name, res["stdout"]))
 			except Exception as e:
 				log.error(e)
 			finally:
@@ -85,9 +89,9 @@ class SiberController(MiddlewareInterface):
 		for server in self.master_server[:1]:
 			res = self.check_port(server.ipaddress, self.siber_cfg["siber"]["port"])
 			if res:
-				log.info(Helper().CHECK_MIDDLEWARE_SERVICE_PORT_SUCCEED.format(server.ipaddress, self.siber_cfg["siber"]["port"]))
+				log.info("机器:{} Siber-nginx代理端口{}访问正常".format(server.ipaddress, self.siber_cfg["siber"]["port"]))
 			else:
-				log.error(Helper().CHECK_MIDDLEWARE_SERVICE_PORT_FAILED.format(server.ipaddress, self.siber_cfg["siber"]["port"]))
+				log.error("机器:{} Siber-nginx代理端口{}访问异常".format(server.ipaddress, self.siber_cfg["siber"]["port"]))
 
 	def send_request(self, url, data):
 		resp = requests.post(url=url, json=data)
@@ -172,14 +176,16 @@ class SiberController(MiddlewareInterface):
 
 	def run_mage_siber_test(self):
 		try:
-			# log.info("替换 Siber env,oss 配置")
+			log.info("替换 Siber env,oss 配置")
 			Mage_test(self.siber_host).replace_private_oss_url()
 			Mage_test(self.siber_host).update_private_mage_env_info()
 			self.update_planversion("v1.15")
 			self.update_basic_planversion("v1.15")
 			self.run_plan("5f1926b438cb970001f5a93d")
 			self.run_plan("5f8ecd1cb2b9fd0001c31217")
-			log.info(Helper().SIBER_CHECK_INFO.format(self.siber_host))
+			log.info("请检查集成测试平台 '私有部署定制化mage plan' 运行结果")
+			log.info("集成测试平台访问地址http://{}:88".format(self.siber_host))
+			log.error("集成测试平台运行失败")
 		except Exception as e:
 			log.error(e)
 			exit(2)
@@ -189,4 +195,4 @@ class SiberController(MiddlewareInterface):
 		self._generic_config()
 		self._start()
 		self._init_siber()
-		self._check()
+		self._check()
\ No newline at end of file
