@@ -5,7 +5,6 @@ import time
 import os
 import socket
 
-from laipvt.helper.errors import Helper
 from laipvt.handler.middlewarehandler import MiddlewareConfigHandler, HarborConfigHandler
 from laipvt.handler.confighandler import CheckResultHandler
 from laipvt.model.cmd import ComposeModel
@@ -14,6 +13,7 @@ from laipvt.sysutil.gvalue import CHECK_INTERVAL
 from laipvt.sysutil.template import FileTemplate
 from laipvt.sysutil.command import RM, MKDIR_DIR, CHMOD_777
 
+
 class MiddlewareInterface():
     def __init__(self, result: CheckResultHandler, handler: MiddlewareConfigHandler, template: str):
         self.check_result = result
@@ -52,12 +52,13 @@ class MiddlewareInterface():
         return False if cfg[self.middleware_name]["is_deploy"] == False else True
 
     def generate_docker_compose_file(self, data_dict) -> bool:
+        log.info("渲染%s docker-compose配置文件" % self.middleware_name)
         FileTemplate(data_dict, self.compose_template, self.docker_compose_file_tmp).fill()
         return True if os.path.isfile(self.docker_compose_file_tmp) else False
 
     def send_docker_compose_file(self):
         for server in self.master_server:
-            log.info(Helper().SEND_FILE.format(self.docker_compose_file_tmp, server.ipaddress, self.docker_compose_file))
+            log.info("分发%s docker-compose配置文件至 %s" % (self.middleware_name, server.ipaddress))
             ssh_cli = ssh_obj(ip=server.ipaddress, user=server.username, password=server.password, port=server.port)
             try:
                 ssh_cli.put(self.docker_compose_file_tmp, self.docker_compose_file)
@@ -68,7 +69,7 @@ class MiddlewareInterface():
                 ssh_cli.close()
 
     def send_docker_compose_file_hosts(self, host):
-        log.info(Helper().SEND_FILE.format(self.docker_compose_file_tmp, host.ipaddress, self.docker_compose_file))
+        log.info("分发%s docker-compose配置文件至 %s:%s" % (self.middleware_name, host.ipaddress, self.docker_compose_file))
         ssh_cli = ssh_obj(ip=host.ipaddress, user=host.username, password=host.password, port=host.port)
         try:
             ssh_cli.put(self.docker_compose_file_tmp, self.docker_compose_file)
@@ -79,7 +80,7 @@ class MiddlewareInterface():
             ssh_cli.close()
 
     def send_config_file(self, server, src, dest, ignore=''):
-        log.info(Helper().SEND_FILE.format(src, server.ipaddress, dest))
+        log.info("分发配置文件{} 到 {}:{}".format(src, server.ipaddress, dest))
         ssh_cli = ssh_obj(ip=server.ipaddress, user=server.username, password=server.password, port=server.port)
         try:
             ssh_cli.put(src, dest, ignore)
@@ -89,31 +90,27 @@ class MiddlewareInterface():
         finally:
             ssh_cli.close()
 
+    def send_docker_compose_file_hosts(self, host):
+        """aa"""
+        log.info("分发%s docker-compose配置文件至 %s:%s" % (self.middleware_name, host.ipaddress, self.docker_compose_file))
+        ssh_cli = ssh_obj(ip=host.ipaddress, user=host.username, password=host.password, port=host.port)
+        try:
+            ssh_cli.put(self.docker_compose_file_tmp, self.docker_compose_file)
+        except Exception as e:
+            log.error(e)
+            exit(2)
+        finally:
+            ssh_cli.close()
+
     def start(self):
         compose_cmd = ComposeModel(self.docker_compose_file)
         for server in self.master_server:
-            log.info(Helper().START_MIDDLEWARE_SERVICE.format(server.ipaddress, self.middleware_name))
+            log.info("启动 %s %s服务" % (server.ipaddress, self.middleware_name))
             ssh_cli = ssh_obj(ip=server.ipaddress, user=server.username, password=server.password, port=server.port)
             try:
                 res = ssh_cli.run_cmd(compose_cmd.up())
                 if res["code"] != 0:
-                    log.error(Helper().START_MIDDLEWARE_SERVICE_ERROR.format(res["stderr"], res["stdout"]))
-                    exit(2)
-            except Exception as e:
-                log.error(e)
-                exit(2)
-            finally:
-                ssh_cli.close()
-
-    def start_all_node(self):
-        compose_cmd = ComposeModel(self.docker_compose_file)
-        for server in self.all_server:
-            log.info(Helper().START_MIDDLEWARE_SERVICE.format(server.ipaddress, self.middleware_name))
-            ssh_cli = ssh_obj(ip=server.ipaddress, user=server.username, password=server.password, port=server.port)
-            try:
-                res = ssh_cli.run_cmd(compose_cmd.up())
-                if res["code"] != 0:
-                    log.error(Helper().START_MIDDLEWARE_SERVICE_ERROR.format(res["stderr"], res["stdout"]))
+                    log.error("启动 %s: %s服务失败.错误原因: %s %s" % (server.ipaddress, self.middleware_name, res["stderr"], res["stdout"]))
                     exit(2)
             except Exception as e:
                 log.error(e)
@@ -124,12 +121,13 @@ class MiddlewareInterface():
     def restart(self):
         compose_cmd = ComposeModel(self.docker_compose_file)
         for server in self.master_server:
-            log.info(Helper().RESTART_MIDDLEWARE_SERVICE.format(server.ipaddress, self.middleware_name))
+            log.info("启动 %s %s服务" % (server.ipaddress, self.middleware_name))
             ssh_cli = ssh_obj(ip=server.ipaddress, user=server.username, password=server.password, port=server.port)
             try:
                 res = ssh_cli.run_cmd(compose_cmd.restart())
                 if res["code"] != 0:
-                    log.error(Helper().START_MIDDLEWARE_SERVICE_ERROR.format(res["stderr"], res["stdout"]))
+                    log.error("启动 %s: %s服务失败.错误原因: %s %s" % (
+                    server.ipaddress, self.middleware_name, res["stderr"], res["stdout"]))
                     exit(2)
             except Exception as e:
                 log.error(e)
@@ -140,13 +138,14 @@ class MiddlewareInterface():
     def reset(self):
         compose_cmd = ComposeModel(self.docker_compose_file)
         for server in self.master_server:
-            log.info(Helper().RESET_MIDDLEWARE_SERVICE.format(server.ipaddress, self.middleware_name))
+            log.info("重新加载 %s %s服务" % (server.ipaddress, self.middleware_name))
             ssh_cli = ssh_obj(ip=server.ipaddress, user=server.username, password=server.password, port=server.port)
             try:
                 res = ssh_cli.run_cmd(compose_cmd.down())
                 res = ssh_cli.run_cmd(compose_cmd.up())
                 if res["code"] != 0:
-                    log.error(Helper().START_MIDDLEWARE_SERVICE_ERROR.format(res["stderr"], res["stdout"]))
+                    log.error("重启 %s: %s服务失败.错误原因: %s %s" % (
+                    server.ipaddress, self.middleware_name, res["stderr"], res["stdout"]))
                     exit(2)
             except Exception as e:
                 log.error(e)
@@ -155,7 +154,7 @@ class MiddlewareInterface():
                 ssh_cli.close()
 
     def create_logs_dir(self, log_path):
-        log.info(Helper().CREATE_LOG_PATH.format(log_path))
+        log.info("创建服务日志目录及授权:{}".format(log_path))
         cmd = [
             MKDIR_DIR.format(log_path),
             CHMOD_777.format(log_path)
